@@ -19,7 +19,34 @@ c     logit mixed model. In this routine, inference is based on the
 c     Polya urn representation of Dirichlet process. The fucntion use the
 c     mixture of normal representation of a logistic distribution. 
 c
-c     Author: A.J.V.
+c     Copyright: Alejandro Jara Vallejos, 2006
+c
+c     This program is free software; you can redistribute it and/or modify
+c     it under the terms of the GNU General Public License as published by
+c     the Free Software Foundation; either version 2 of the License, or (at
+c     your option) any later version.
+c
+c     This program is distributed in the hope that it will be useful, but
+c     WITHOUT ANY WARRANTY; without even the implied warranty of
+c     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+c     General Public License for more details.
+c
+c     You should have received a copy of the GNU General Public License
+c     along with this program; if not, write to the Free Software
+c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+c
+c     The author's contact information:
+c
+c     Alejandro Jara Vallejos
+c     Biostatistical Centre
+c     Katholieke Universiteit Leuven
+c     U.Z. Sint-Rafal
+c     Kapucijnenvoer 35
+c     B-3000 Leuven
+c     Voice: +32 (0)16 336892 
+c     Fax  : +32 (0)16 337015 
+c     URL  : http://student.kuleuven.be/~s0166452/
+c     Email: Alejandro.JaraVallejos@med.kuleuven.be
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -267,6 +294,9 @@ c+++++Working space
       logical ainf,asup
       parameter(tpi=6.283185307179586476925286766559d0)
 
+c+++++CPU time
+      real*8 sec00,sec0,sec1,sec
+
 c++++ parameters
       nburn=mcmc(1)
       nskip=mcmc(2)
@@ -283,7 +313,7 @@ c++++ set random number generator
       seed2=seed(2)
       seed3=seed(3)
 
-      call setrand(seed1,seed2,seed3)
+      call setall(seed1,seed2)
      
 c++++ cluster structure
 
@@ -300,6 +330,9 @@ c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
       skipcount=0
       dispcount=0
       nscan=nburn+(nskip+1)*(nsave)
+
+      call cpu_time(sec0)
+      sec00=0.d0
       
       do iscan=1,nscan
 
@@ -1046,8 +1079,11 @@ c+++++++++++++ cpo
 c+++++++++++++ print
                skipcount = 0
                if(dispcount.ge.ndisplay)then
-c                  call intpr("isave",5,isave,1)
-                  tmp1=sprint(isave,nsave)                  
+                  call cpu_time(sec1)
+                  sec00=sec00+(sec1-sec0)
+                  sec=sec00
+                  sec0=sec1
+                  tmp1=sprint(isave,nsave,sec)
                   dispcount=0
                end if   
             end if
