@@ -26,6 +26,13 @@ double F77_SUB(cdflnorm)(double *x, double *logmean, double *logsd, int *lower_t
 }
 
 
+double F77_SUB(cdfbetas)(double *x, double *a, double *b, int *lower_tail, int *give_log)
+{
+	return pbeta(*x, *a, *b, *lower_tail, *give_log);
+}
+
+
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////
 //Quantile
 ///////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -55,6 +62,18 @@ int F77_SUB(invcdfbinom)(double *p, int *size, double *prob, int *lower_tail, in
 }
 
 
+int F77_SUB(invcdfbetas)(double *p, double *a, double *b, int *lower_tail, int *log_p)
+{
+	return qbeta(*p, *a, *b, *lower_tail, *log_p);
+}
+
+
+double F77_SUB(invcdfchisq)(double *p, double *df, int *lower_tail, int *log_p)
+{
+	return qchisq(*p, *df, *lower_tail, *log_p);
+}
+
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////
 //Density
 ///////////////////////////////////////////////////////////////////////////////////////////////////////
